# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/iv_svi_parameters_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.sdk/stream/iv_svi_parameters_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x03\n\x1fStreamIvSviParametersResponseV1\x12\x33\n\x0f\x64\x61ta_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rdata_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\texchanges\x18\x04 \x03(\t\x12\x0c\n\x04\x62\x61se\x18\x05 \x01(\t\x12\r\n\x05quote\x18\x06 \x01(\t\x12\x16\n\x0etime_to_expiry\x18\x07 \x01(\t\x12\x1c\n\x14\x61tm_implied_variance\x18\x08 \x01(\t\x12\x10\n\x08\x61tm_skew\x18\t \x01(\t\x12\x12\n\nleft_slope\x18\n \x01(\t\x12\x13\n\x0bright_slope\x18\x0b \x01(\t\x12\x1c\n\x14min_implied_variance\x18\x0c \x01(\t\x12\x14\n\x0c\x63urrent_spot\x18\r \x01(\t\x12\x15\n\rinterest_rate\x18\x0e \x01(\t\x12,\n\x08ts_event\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xa4\x01\n)com.kaiko.sdk.stream.iv_svi_parameters_v1P\x01ZRgithub.com/kaikodata/kaiko-go-sdk/stream/iv_svi_parameters_v1;iv_svi_parameters_v1\xaa\x02 KaikoSdk.Stream.IvSviParameterV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.iv_svi_parameters_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.kaiko.sdk.stream.iv_svi_parameters_v1P\001ZRgithub.com/kaikodata/kaiko-go-sdk/stream/iv_svi_parameters_v1;iv_svi_parameters_v1\252\002 KaikoSdk.Stream.IvSviParameterV1'
  _globals['_STREAMIVSVIPARAMETERSRESPONSEV1']._serialized_start=94
  _globals['_STREAMIVSVIPARAMETERSRESPONSEV1']._serialized_end=557
# @@protoc_insertion_point(module_scope)
