# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/commodity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#sdk/stream/index_v1/commodity.proto\x12\x08kaikosdk*P\n\x14StreamIndexCommodity\x12\x0f\n\x0bSIC_UNKNOWN\x10\x00\x12\x11\n\rSIC_REAL_TIME\x10\x01\x12\x14\n\x10SIC_DAILY_FIXING\x10\x02\x42w\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_v1.commodity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.kaiko.sdk.stream.index_v1P\001Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1'
  _globals['_STREAMINDEXCOMMODITY']._serialized_start=49
  _globals['_STREAMINDEXCOMMODITY']._serialized_end=129
# @@protoc_insertion_point(module_scope)
