# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto\x12\x08kaikosdk*`\n*StreamDerivativesInstrumentCommodityKindV1\x12\x11\n\rSDICK_UNKNOWN\x10\x00\x12\x0f\n\x0bSDICK_PRICE\x10\x01\x12\x0e\n\nSDICK_RISK\x10\x02\x42\xd9\x01\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\x01Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\xaa\x02.KaikoSdk.Stream.DerivativesInstrumentMetricsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.derivatives_instrument_metrics_v1.commodity_kind_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\001Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\252\002.KaikoSdk.Stream.DerivativesInstrumentMetricsV1'
  _globals['_STREAMDERIVATIVESINSTRUMENTCOMMODITYKINDV1']._serialized_start=79
  _globals['_STREAMDERIVATIVESINSTRUMENTCOMMODITYKINDV1']._serialized_end=175
# @@protoc_insertion_point(module_scope)
