# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregated_quote_v2/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-sdk/stream/aggregated_quote_v2/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x1aStreamAggregatedQuoteValue\x12\r\n\x05price\x18\x01 \x01(\t\x12\x0e\n\x06volume\x18\x02 \x01(\t\"\xf7\x02\n\x1fStreamAggregatedQuoteResponseV2\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\x18\n\x10instrument_class\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12G\n\nevent_type\x18\x04 \x01(\x0e\x32\x33.kaikosdk.StreamAggregatedQuoteResponseV2.EventType\x12,\n\x08ts_event\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x06vetted\x18\x06 \x01(\x0b\x32$.kaikosdk.StreamAggregatedQuoteValue\x12\x36\n\x08unvetted\x18\x07 \x01(\x0b\x32$.kaikosdk.StreamAggregatedQuoteValue\"4\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x42\x45ST_ASK\x10\x01\x12\x0c\n\x08\x42\x45ST_BID\x10\x02\x42\xa2\x01\n(com.kaiko.sdk.stream.aggregated_quote_v2P\x01ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\xaa\x02!KaikoSdk.Stream.AggregatedQuoteV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregated_quote_v2.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.kaiko.sdk.stream.aggregated_quote_v2P\001ZPgithub.com/kaikodata/kaiko-go-sdk/stream/aggregated_quote_v2;aggregated_quote_v2\252\002!KaikoSdk.Stream.AggregatedQuoteV2'
  _globals['_STREAMAGGREGATEDQUOTEVALUE']._serialized_start=92
  _globals['_STREAMAGGREGATEDQUOTEVALUE']._serialized_end=151
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2']._serialized_start=154
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2']._serialized_end=529
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2_EVENTTYPE']._serialized_start=477
  _globals['_STREAMAGGREGATEDQUOTERESPONSEV2_EVENTTYPE']._serialized_end=529
# @@protoc_insertion_point(module_scope)
