# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/market_update_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import wrappers_pb2 as sdk_dot_core_dot_wrappers__pb2
from kaikosdk.stream.market_update_v1 import commodity_pb2 as sdk_dot_stream_dot_market__update__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sdk/stream/market_update_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17sdk/core/wrappers.proto\x1a+sdk/stream/market_update_v1/commodity.proto\"\x83\x08\n\x1cStreamMarketUpdateResponseV1\x12\x38\n\tcommodity\x18\x01 \x01(\x0e\x32%.kaikosdk.StreamMarketUpdateCommodity\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12\x13\n\x0bsequence_id\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\r\n\x05price\x18\x08 \x01(\x01\x12-\n\x0bts_exchange\x18\t \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12/\n\rts_collection\x18\n \x01(\x0b\x32\x18.kaikosdk.TimestampValue\x12,\n\x08ts_event\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12R\n\x0bupdate_type\x18\x0c \x01(\x0e\x32=.kaikosdk.StreamMarketUpdateResponseV1.StreamMarketUpdateType\x12\x41\n\x08snapshot\x18\r \x01(\x0b\x32/.kaikosdk.StreamMarketUpdateResponseV1.Snapshot\x12_\n\x15\x61\x64\x64itional_properties\x18\x0e \x03(\x0b\x32@.kaikosdk.StreamMarketUpdateResponseV1.AdditionalPropertiesEntry\x1a\xbc\x01\n\x08Snapshot\x12\x43\n\x04\x61sks\x18\x01 \x03(\x0b\x32\x35.kaikosdk.StreamMarketUpdateResponseV1.Snapshot.Order\x12\x43\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x35.kaikosdk.StreamMarketUpdateResponseV1.Snapshot.Order\x1a&\n\x05Order\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x16StreamMarketUpdateType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tTRADE_BUY\x10\x01\x12\x0e\n\nTRADE_SELL\x10\x02\x12\x11\n\rTRADE_UNKNOWN\x10\t\x12\x0c\n\x08\x42\x45ST_ASK\x10\x03\x12\x0c\n\x08\x42\x45ST_BID\x10\x04\x12\x0f\n\x0bUPDATED_ASK\x10\x05\x12\x0f\n\x0bUPDATED_BID\x10\x06\x12\x0c\n\x08SNAPSHOT\x10\x07\x12\x12\n\x0e\x46ORCE_SNAPSHOT\x10\x08\x42\x96\x01\n%com.kaiko.sdk.stream.market_update_v1P\x01ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\xaa\x02\x1eKaikoSdk.Stream.MarketUpdateV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.market_update_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.kaiko.sdk.stream.market_update_v1P\001ZJgithub.com/kaikodata/kaiko-go-sdk/stream/market_update_v1;market_update_v1\252\002\036KaikoSdk.Stream.MarketUpdateV1'
  _STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY._options = None
  _STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_STREAMMARKETUPDATERESPONSEV1']._serialized_start=160
  _globals['_STREAMMARKETUPDATERESPONSEV1']._serialized_end=1187
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT']._serialized_start=752
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT']._serialized_end=940
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT_ORDER']._serialized_start=902
  _globals['_STREAMMARKETUPDATERESPONSEV1_SNAPSHOT_ORDER']._serialized_end=940
  _globals['_STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_start=942
  _globals['_STREAMMARKETUPDATERESPONSEV1_ADDITIONALPROPERTIESENTRY']._serialized_end=1001
  _globals['_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE']._serialized_start=1004
  _globals['_STREAMMARKETUPDATERESPONSEV1_STREAMMARKETUPDATETYPE']._serialized_end=1187
# @@protoc_insertion_point(module_scope)
