# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/sdk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.stream.aggregated_price_v1 import request_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_request__pb2
from kaikosdk.stream.aggregated_price_v1 import response_pb2 as sdk_dot_stream_dot_aggregated__price__v1_dot_response__pb2
from kaikosdk.stream.aggregated_quote_v2 import request_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_request__pb2
from kaikosdk.stream.aggregated_quote_v2 import response_pb2 as sdk_dot_stream_dot_aggregated__quote__v2_dot_response__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_direct_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__direct__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_request__pb2
from kaikosdk.stream.aggregates_ohlcv_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__ohlcv__v1_dot_response__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import request_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_request__pb2
from kaikosdk.stream.aggregates_spot_exchange_rate_v2 import response_pb2 as sdk_dot_stream_dot_aggregates__spot__exchange__rate__v2_dot_response__pb2
from kaikosdk.stream.aggregates_vwap_v1 import request_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_request__pb2
from kaikosdk.stream.aggregates_vwap_v1 import response_pb2 as sdk_dot_stream_dot_aggregates__vwap__v1_dot_response__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import request_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_request__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import response_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_response__pb2
from kaikosdk.stream.exotic_indices_v1 import request_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_request__pb2
from kaikosdk.stream.exotic_indices_v1 import response_pb2 as sdk_dot_stream_dot_exotic__indices__v1_dot_response__pb2
from kaikosdk.stream.index_forex_rate_v1 import request_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_request__pb2
from kaikosdk.stream.index_forex_rate_v1 import response_pb2 as sdk_dot_stream_dot_index__forex__rate__v1_dot_response__pb2
from kaikosdk.stream.index_multi_assets_v1 import request_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_request__pb2
from kaikosdk.stream.index_multi_assets_v1 import response_pb2 as sdk_dot_stream_dot_index__multi__assets__v1_dot_response__pb2
from kaikosdk.stream.index_v1 import request_pb2 as sdk_dot_stream_dot_index__v1_dot_request__pb2
from kaikosdk.stream.index_v1 import response_pb2 as sdk_dot_stream_dot_index__v1_dot_response__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import request_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_request__pb2
from kaikosdk.stream.iv_svi_parameters_v1 import response_pb2 as sdk_dot_stream_dot_iv__svi__parameters__v1_dot_response__pb2
from kaikosdk.stream.market_update_v1 import request_pb2 as sdk_dot_stream_dot_market__update__v1_dot_request__pb2
from kaikosdk.stream.market_update_v1 import response_pb2 as sdk_dot_stream_dot_market__update__v1_dot_response__pb2
from kaikosdk.stream.trades_v1 import request_pb2 as sdk_dot_stream_dot_trades__v1_dot_request__pb2
from kaikosdk.stream.trades_v1 import response_pb2 as sdk_dot_stream_dot_trades__v1_dot_response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsdk/sdk.proto\x12\x08kaikosdk\x1a,sdk/stream/aggregated_price_v1/request.proto\x1a-sdk/stream/aggregated_price_v1/response.proto\x1a,sdk/stream/aggregated_quote_v2/request.proto\x1a-sdk/stream/aggregated_quote_v2/response.proto\x1a;sdk/stream/aggregates_direct_exchange_rate_v2/request.proto\x1a<sdk/stream/aggregates_direct_exchange_rate_v2/response.proto\x1a,sdk/stream/aggregates_ohlcv_v1/request.proto\x1a-sdk/stream/aggregates_ohlcv_v1/response.proto\x1a\x39sdk/stream/aggregates_spot_exchange_rate_v2/request.proto\x1a:sdk/stream/aggregates_spot_exchange_rate_v2/response.proto\x1a+sdk/stream/aggregates_vwap_v1/request.proto\x1a,sdk/stream/aggregates_vwap_v1/response.proto\x1a:sdk/stream/derivatives_instrument_metrics_v1/request.proto\x1a;sdk/stream/derivatives_instrument_metrics_v1/response.proto\x1a*sdk/stream/exotic_indices_v1/request.proto\x1a+sdk/stream/exotic_indices_v1/response.proto\x1a,sdk/stream/index_forex_rate_v1/request.proto\x1a-sdk/stream/index_forex_rate_v1/response.proto\x1a.sdk/stream/index_multi_assets_v1/request.proto\x1a/sdk/stream/index_multi_assets_v1/response.proto\x1a!sdk/stream/index_v1/request.proto\x1a\"sdk/stream/index_v1/response.proto\x1a-sdk/stream/iv_svi_parameters_v1/request.proto\x1a.sdk/stream/iv_svi_parameters_v1/response.proto\x1a)sdk/stream/market_update_v1/request.proto\x1a*sdk/stream/market_update_v1/response.proto\x1a\"sdk/stream/trades_v1/request.proto\x1a#sdk/stream/trades_v1/response.proto2\x86\x01\n\x1eStreamAggregatedQuoteServiceV2\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamAggregatedQuoteRequestV2\x1a).kaikosdk.StreamAggregatedQuoteResponseV2\"\x00\x30\x01\x32\x89\x01\n\x1eStreamAggregatedPriceServiceV1\x12g\n\tSubscribe\x12(.kaikosdk.StreamAggregatedPriceRequestV1\x1a).kaikosdk.StreamAggregatedPriceResponseV1\"\x03\x88\x02\x01\x30\x01\x32\x86\x01\n\x1eStreamAggregatesOHLCVServiceV1\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamAggregatesOHLCVRequestV1\x1a).kaikosdk.StreamAggregatesOHLCVResponseV1\"\x00\x30\x01\x32k\n\x15StreamTradesServiceV1\x12R\n\tSubscribe\x12\x1f.kaikosdk.StreamTradesRequestV1\x1a .kaikosdk.StreamTradesResponseV1\"\x00\x30\x01\x32\x83\x01\n\x1dStreamAggregatesVWAPServiceV1\x12\x62\n\tSubscribe\x12\'.kaikosdk.StreamAggregatesVWAPRequestV1\x1a(.kaikosdk.StreamAggregatesVWAPResponseV1\"\x00\x30\x01\x32v\n\x14StreamIndexServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamIndexServiceRequestV1\x1a&.kaikosdk.StreamIndexServiceResponseV1\"\x00\x30\x01\x32\x97\x01\n\x1fStreamIndexMultiAssetsServiceV1\x12t\n\tSubscribe\x12\x30.kaikosdk.StreamIndexMultiAssetsServiceRequestV1\x1a\x31.kaikosdk.StreamIndexMultiAssetsServiceResponseV1\"\x00\x30\x01\x32}\n\x1bStreamMarketUpdateServiceV1\x12^\n\tSubscribe\x12%.kaikosdk.StreamMarketUpdateRequestV1\x1a&.kaikosdk.StreamMarketUpdateResponseV1\"\x00\x30\x01\x32\xad\x01\n+StreamAggregatesSpotExchangeRateV2ServiceV1\x12~\n\tSubscribe\x12\x35.kaikosdk.StreamAggregatesSpotExchangeRateV2RequestV1\x1a\x36.kaikosdk.StreamAggregatesSpotExchangeRateV2ResponseV1\"\x00\x30\x01\x32\xb8\x01\n1StreamAggregatesSpotDirectExchangeRateV2ServiceV1\x12\x82\x01\n\tSubscribe\x12\x37.kaikosdk.StreamAggregatesDirectExchangeRateV2RequestV1\x1a\x38.kaikosdk.StreamAggregatesDirectExchangeRateV2ResponseV1\"\x00\x30\x01\x32\x91\x01\n\x1dStreamIndexForexRateServiceV1\x12p\n\tSubscribe\x12..kaikosdk.StreamIndexForexRateServiceRequestV1\x1a/.kaikosdk.StreamIndexForexRateServiceResponseV1\"\x00\x30\x01\x32\xad\x01\n+StreamDerivativesInstrumentMetricsServiceV1\x12~\n\tSubscribe\x12\x35.kaikosdk.StreamDerivativesInstrumentMetricsRequestV1\x1a\x36.kaikosdk.StreamDerivativesInstrumentMetricsResponseV1\"\x00\x30\x01\x32\x86\x01\n\x1eStreamIvSviParametersServiceV1\x12\x64\n\tSubscribe\x12(.kaikosdk.StreamIvSviParametersRequestV1\x1a).kaikosdk.StreamIvSviParametersResponseV1\"\x00\x30\x01\x32\x8e\x01\n\x1cStreamExoticIndicesServiceV1\x12n\n\tSubscribe\x12-.kaikosdk.StreamExoticIndicesServiceRequestV1\x1a..kaikosdk.StreamExoticIndicesServiceResponseV1\"\x00\x30\x01\x42R\n\rcom.kaiko.sdkB\x08SdkProtoP\x01Z*github.com/kaikodata/kaiko-go-sdk;kaikosdk\xaa\x02\x08KaikoSdkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.sdk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.kaiko.sdkB\010SdkProtoP\001Z*github.com/kaikodata/kaiko-go-sdk;kaikosdk\252\002\010KaikoSdk'
  _STREAMAGGREGATEDPRICESERVICEV1.methods_by_name['Subscribe']._options = None
  _STREAMAGGREGATEDPRICESERVICEV1.methods_by_name['Subscribe']._serialized_options = b'\210\002\001'
  _globals['_STREAMAGGREGATEDQUOTESERVICEV2']._serialized_start=1366
  _globals['_STREAMAGGREGATEDQUOTESERVICEV2']._serialized_end=1500
  _globals['_STREAMAGGREGATEDPRICESERVICEV1']._serialized_start=1503
  _globals['_STREAMAGGREGATEDPRICESERVICEV1']._serialized_end=1640
  _globals['_STREAMAGGREGATESOHLCVSERVICEV1']._serialized_start=1643
  _globals['_STREAMAGGREGATESOHLCVSERVICEV1']._serialized_end=1777
  _globals['_STREAMTRADESSERVICEV1']._serialized_start=1779
  _globals['_STREAMTRADESSERVICEV1']._serialized_end=1886
  _globals['_STREAMAGGREGATESVWAPSERVICEV1']._serialized_start=1889
  _globals['_STREAMAGGREGATESVWAPSERVICEV1']._serialized_end=2020
  _globals['_STREAMINDEXSERVICEV1']._serialized_start=2022
  _globals['_STREAMINDEXSERVICEV1']._serialized_end=2140
  _globals['_STREAMINDEXMULTIASSETSSERVICEV1']._serialized_start=2143
  _globals['_STREAMINDEXMULTIASSETSSERVICEV1']._serialized_end=2294
  _globals['_STREAMMARKETUPDATESERVICEV1']._serialized_start=2296
  _globals['_STREAMMARKETUPDATESERVICEV1']._serialized_end=2421
  _globals['_STREAMAGGREGATESSPOTEXCHANGERATEV2SERVICEV1']._serialized_start=2424
  _globals['_STREAMAGGREGATESSPOTEXCHANGERATEV2SERVICEV1']._serialized_end=2597
  _globals['_STREAMAGGREGATESSPOTDIRECTEXCHANGERATEV2SERVICEV1']._serialized_start=2600
  _globals['_STREAMAGGREGATESSPOTDIRECTEXCHANGERATEV2SERVICEV1']._serialized_end=2784
  _globals['_STREAMINDEXFOREXRATESERVICEV1']._serialized_start=2787
  _globals['_STREAMINDEXFOREXRATESERVICEV1']._serialized_end=2932
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSSERVICEV1']._serialized_start=2935
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSSERVICEV1']._serialized_end=3108
  _globals['_STREAMIVSVIPARAMETERSSERVICEV1']._serialized_start=3111
  _globals['_STREAMIVSVIPARAMETERSSERVICEV1']._serialized_end=3245
  _globals['_STREAMEXOTICINDICESSERVICEV1']._serialized_start=3248
  _globals['_STREAMEXOTICINDICESSERVICEV1']._serialized_end=3390
# @@protoc_insertion_point(module_scope)
