# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/index_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"sdk/stream/index_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x83\x01\n$StreamIndexServiceResponsePercentage\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x38\n\x05pairs\x18\x03 \x03(\x0b\x32).kaikosdk.StreamIndexServiceResponsePairs\"\x85\x01\n\x1fStreamIndexServiceResponsePairs\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x44\n\x0binstruments\x18\x03 \x03(\x0b\x32/.kaikosdk.StreamIndexServiceResponseInstruments\"\x7f\n!StreamIndexServiceUnderlyingTrade\x12\x0e\n\x06volume\x18\x01 \x01(\x01\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12,\n\x08\x64\x61tetime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaf\x01\n%StreamIndexServiceResponseInstruments\x12\x11\n\tpartition\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\x45\n\x10underlying_trade\x18\x05 \x01(\x0b\x32+.kaikosdk.StreamIndexServiceUnderlyingTrade\"D\n#StreamIndexServiceResponseBaseAsset\x12\r\n\x05\x61sset\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\"\xad\x03\n\x1cStreamIndexServiceResponseV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x31\n\tcommodity\x18\x02 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataInterval\x12\r\n\x05quote\x18\x04 \x01(\t\x12<\n\x05\x62\x61ses\x18\x05 \x03(\x0b\x32-.kaikosdk.StreamIndexServiceResponseBaseAsset\x12\x11\n\texchanges\x18\x06 \x03(\t\x12\x43\n\x0bpercentages\x18\x07 \x03(\x0b\x32..kaikosdk.StreamIndexServiceResponsePercentage\x12,\n\x08ts_event\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bsequence_id\x18\t \x01(\t\x12\x34\n\x10last_ingest_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampBw\n\x1d\x63om.kaiko.sdk.stream.index_v1P\x01Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\xaa\x02\x17KaikoSdk.Stream.IndexV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.index_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.kaiko.sdk.stream.index_v1P\001Z:github.com/kaikodata/kaiko-go-sdk/stream/index_v1;index_v1\252\002\027KaikoSdk.Stream.IndexV1'
  _globals['_STREAMINDEXSERVICERESPONSEPERCENTAGE']._serialized_start=149
  _globals['_STREAMINDEXSERVICERESPONSEPERCENTAGE']._serialized_end=280
  _globals['_STREAMINDEXSERVICERESPONSEPAIRS']._serialized_start=283
  _globals['_STREAMINDEXSERVICERESPONSEPAIRS']._serialized_end=416
  _globals['_STREAMINDEXSERVICEUNDERLYINGTRADE']._serialized_start=418
  _globals['_STREAMINDEXSERVICEUNDERLYINGTRADE']._serialized_end=545
  _globals['_STREAMINDEXSERVICERESPONSEINSTRUMENTS']._serialized_start=548
  _globals['_STREAMINDEXSERVICERESPONSEINSTRUMENTS']._serialized_end=723
  _globals['_STREAMINDEXSERVICERESPONSEBASEASSET']._serialized_start=725
  _globals['_STREAMINDEXSERVICERESPONSEBASEASSET']._serialized_end=793
  _globals['_STREAMINDEXSERVICERESPONSEV1']._serialized_start=796
  _globals['_STREAMINDEXSERVICERESPONSEV1']._serialized_end=1225
# @@protoc_insertion_point(module_scope)
