# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_vwap_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,sdk/stream/aggregates_vwap_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc1\x01\n\x1eStreamAggregatesVWAPResponseV1\x12\x11\n\taggregate\x18\x01 \x01(\t\x12\r\n\x05\x63lass\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\x13\n\x0bsequence_id\x18\x05 \x01(\t\x12\r\n\x05price\x18\x06 \x01(\x01\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03uid\x18\x08 \x01(\tB\x9e\x01\n\'com.kaiko.sdk.stream.aggregates_vwap_v1P\x01ZNgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_vwap_v1;aggregates_vwap_v1\xaa\x02 KaikoSdk.Stream.AggregatesVWAPV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_vwap_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.kaiko.sdk.stream.aggregates_vwap_v1P\001ZNgithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_vwap_v1;aggregates_vwap_v1\252\002 KaikoSdk.Stream.AggregatesVWAPV1'
  _globals['_STREAMAGGREGATESVWAPRESPONSEV1']._serialized_start=92
  _globals['_STREAMAGGREGATESVWAPRESPONSEV1']._serialized_end=285
# @@protoc_insertion_point(module_scope)
