# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_instrument_metrics_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import commodity_kind_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_commodity__kind__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;sdk/stream/derivatives_instrument_metrics_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41sdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto\"\xa8\x02\n,StreamDerivativesInstrumentMetricsResponseV1\x12\r\n\x05value\x18\x01 \x01(\t\x12\x15\n\rlegacy_symbol\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x11\n\tcommodity\x18\x04 \x01(\t\x12L\n\x0e\x63ommodity_kind\x18\x05 \x01(\x0e\x32\x34.kaikosdk.StreamDerivativesInstrumentCommodityKindV1\x12\x31\n\rts_collection\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08ts_event\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xd9\x01\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\x01Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\xaa\x02.KaikoSdk.Stream.DerivativesInstrumentMetricsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.derivatives_instrument_metrics_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\001Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\252\002.KaikoSdk.Stream.DerivativesInstrumentMetricsV1'
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSRESPONSEV1']._serialized_start=174
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSRESPONSEV1']._serialized_end=470
# @@protoc_insertion_point(module_scope)
