# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregates_direct_exchange_rate_v2/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from kaikosdk.core import assets_pb2 as sdk_dot_core_dot_assets__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;sdk/stream/aggregates_direct_exchange_rate_v2/request.proto\x12\x08kaikosdk\x1a\x1egoogle/protobuf/duration.proto\x1a\x15sdk/core/assets.proto\"\xe7\x01\n-StreamAggregatesDirectExchangeRateV2RequestV1\x12 \n\x06\x61ssets\x18\x01 \x01(\x0b\x32\x10.kaikosdk.Assets\x12)\n\x06window\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11include_exchanges\x18\x03 \x03(\t\x12\x19\n\x11\x65xclude_exchanges\x18\x04 \x03(\t\x12\x33\n\x10update_frequency\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\xdc\x01\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\x01Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\xaa\x02.KaikoSdk.Stream.AggregatesDirectExchangeRateV2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregates_direct_exchange_rate_v2.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.kaiko.sdk.stream.aggregates_direct_exchange_rate_v2P\001Zngithub.com/kaikodata/kaiko-go-sdk/stream/aggregates_direct_exchange_rate_v2;aggregates_direct_exchange_rate_v2\252\002.KaikoSdk.Stream.AggregatesDirectExchangeRateV2'
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2REQUESTV1']._serialized_start=129
  _globals['_STREAMAGGREGATESDIRECTEXCHANGERATEV2REQUESTV1']._serialized_end=360
# @@protoc_insertion_point(module_scope)
