# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/exotic_indices_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import data_interval_pb2 as sdk_dot_core_dot_data__interval__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*sdk/stream/exotic_indices_v1/request.proto\x12\x08kaikosdk\x1a\x1csdk/core/data_interval.proto\x1a#sdk/stream/index_v1/commodity.proto\"\x98\x01\n#StreamExoticIndicesServiceRequestV1\x12\x12\n\nindex_code\x18\x01 \x01(\t\x12\x33\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12(\n\x08interval\x18\x03 \x01(\x0b\x32\x16.kaikosdk.DataIntervalB\x9a\x01\n&com.kaiko.sdk.stream.exotic_indices_v1P\x01ZLgithub.com/kaikodata/kaiko-go-sdk/stream/exotic_indices_v1;exotic_indices_v1\xaa\x02\x1fKaikoSdk.Stream.ExoticIndicesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.exotic_indices_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.kaiko.sdk.stream.exotic_indices_v1P\001ZLgithub.com/kaikodata/kaiko-go-sdk/stream/exotic_indices_v1;exotic_indices_v1\252\002\037KaikoSdk.Stream.ExoticIndicesV1'
  _globals['_STREAMEXOTICINDICESSERVICEREQUESTV1']._serialized_start=124
  _globals['_STREAMEXOTICINDICESSERVICEREQUESTV1']._serialized_end=276
# @@protoc_insertion_point(module_scope)
